@@ -162,7 +162,7 @@ pub trait SpatialTriangle {
     }
 
     #[inline]
-    fn intersect4(&self, packet: &mut crate::RayPacket4, t_min: &[f32; 4]) -> Option<[bool; 4]> {
+    fn intersect4(&self, packet: &mut crate::RayPacket4, t_min: Vec4) -> Option<[bool; 4]> {
         let v0 = self.vertex0();
         let v1 = self.vertex1();
         let v2 = self.vertex2();
@@ -170,14 +170,6 @@ pub trait SpatialTriangle {
         let zero = Vec4::ZERO;
         let one = Vec4::ONE;
 
-        let org_x = packet.origin_x;
-        let org_y = packet.origin_y;
-        let org_z = packet.origin_z;
-
-        let dir_x = packet.direction_x;
-        let dir_y = packet.direction_y;
-        let dir_z = packet.direction_z;
-
         let p0_x = v0.xxxx();
         let p0_y = v0.yyyy();
         let p0_z = v0.zzzz();
@@ -198,9 +190,9 @@ pub trait SpatialTriangle {
         let edge2_y = p2_y - p0_y;
         let edge2_z = p2_z - p0_z;
 
-        let h_x = (dir_y * edge2_z) - (dir_z * edge2_y);
-        let h_y = (dir_z * edge2_x) - (dir_x * edge2_z);
-        let h_z = (dir_x * edge2_y) - (dir_y * edge2_x);
+        let h_x = (packet.direction_y * edge2_z) - (packet.direction_z * edge2_y);
+        let h_y = (packet.direction_z * edge2_x) - (packet.direction_x * edge2_z);
+        let h_z = (packet.direction_x * edge2_y) - (packet.direction_y * edge2_x);
 
         let a = (edge1_x * h_x) + (edge1_y * h_y) + (edge1_z * h_z);
         let epsilon = Vec4::from([1e-6; 4]);
@@ -210,9 +202,9 @@ pub trait SpatialTriangle {
         }
 
         let f = one / a;
-        let s_x = org_x - p0_x;
-        let s_y = org_y - p0_y;
-        let s_z = org_z - p0_z;
+        let s_x = packet.origin_x - p0_x;
+        let s_y = packet.origin_y - p0_y;
+        let s_z = packet.origin_z - p0_z;
 
         let u = f * ((s_x * h_x) + (s_y * h_y) + (s_z * h_z));
         let mask = mask.bitand(u.cmpge(zero) & u.cmple(one));
@@ -224,14 +216,15 @@ pub trait SpatialTriangle {
         let q_y = s_z * edge1_x - s_x * edge1_z;
         let q_z = s_x * edge1_y - s_y * edge1_x;
 
-        let v = f * ((dir_x * q_x) + (dir_y * q_y) + (dir_z * q_z));
+        let v = f
+            * ((packet.direction_x * q_x)
+                + (packet.direction_y * q_y)
+                + (packet.direction_z * q_z));
         let mask = mask.bitand(v.cmpge(zero) & (u + v).cmple(one));
         if mask.bitmask() == 0 {
             return None;
         }
 
-        let t_min = Vec4::from(*t_min);
-
         let t_value = f * ((edge2_x * q_x) + (edge2_y * q_y) + (edge2_z * q_z));
         let mask = mask.bitand(t_value.cmpge(t_min) & t_value.cmplt(packet.t));
         let bitmask = mask.bitmask();
